function OUprocess
% In this exercise we simulated N paths of a OU process
% dX_t = \lambda (\nu-X_t) dt + \sigma dW_t, X_0 =x and simulate the
% expecation of X_1, X_1^2, X_1^+
tic
%% parameter input
% horizon
T=1;
% sample size
Nsimu=10^5;
Nplot=Nsimu;
% grid points
M=10^3;
% volatility
sigma=0.3;
lambda=1;
nu=1.2;
x=1;
% time step
dt= T/M;

% theoretical value for the expectation, second moment and pos part
mutilde = x*exp(-lambda*T)+ nu*(1-exp(-lambda*T));
sigmatilde= sqrt(sigma^2/(2*lambda)*(1-exp(-2*lambda*T)));
theoreticalvalueexp= mutilde;
theoreticalvaluesec= sigmatilde^2+mutilde^2;
theoreticalvaluepos= mutilde*normcdf(mutilde/sigmatilde)+sigmatilde/sqrt(2*pi)*exp(-1/2*(mutilde/sigmatilde)^2);
%% Simulation
% BM
BM = [zeros(1,Nplot);sqrt(T/M)*cumsum(randn(M,Nplot))];
OU = [x*ones(1,Nplot);zeros(M,Nplot)];
% the process X^(b)
for i =1:M
    OU(i+1,:)=OU(i,:)+lambda*(nu-OU(i,:))*dt+ sigma.*(BM(i+1,:)-BM(i,:));
end

%plot the first 10 sample paths
timegrid= 0:dt:T;
plot(timegrid,OU(:,1:10))

%compute simulated value
simulatedvalueexp= mean(OU(end,:));
simulatedvaluesec= mean(OU(end,:).^2);
simulatedvaluepos= mean(subplus(OU(end,:)));

disp('Exact values: Expectation/2.Moment/pos. part')
disp([theoreticalvalueexp;theoreticalvaluesec;theoreticalvaluepos])
disp('Estimated value: Expectation/2.Moment/pos. part')
disp([simulatedvalueexp;simulatedvaluesec;simulatedvaluepos])

%estimated variance
%estvarexp= var(OU(end,:));
%estvarsec= var(OU(end,:).^2);
%estvarpos= var(subplus(OU(end,:)));
% confidence interval using CLT
%cfplusexp=simulatedvalueexp+1.96*sqrt(estvarexp/Nsimu);
%cfminusexp=simulatedvalueexp-1.96*sqrt(estvarexp/Nsimu);
%cfplussec=simulatedvaluesec+1.96*sqrt(estvarsec/Nsimu);
%cfminussec=simulatedvaluesec-1.96*sqrt(estvarsec/Nsimu);
%cfpluspos=simulatedvaluepos+1.96*sqrt(estvarpos/Nsimu);
%cfminuspos=simulatedvaluepos-1.96*sqrt(estvarpos/Nsimu);

%disp('Confidence interval: ')
%disp([cfminusexp,cfplusexp; cfminussec,cfplussec;cfminuspos,cfpluspos])

toc